@@ -103,10 +103,10 @@ async def make_ass_file_subtitle(
     for subtitle in json_files:
         if subtitle["lan_doc"] == name:
             url = subtitle["subtitle_url"]
-            async with get_session().request("GET", url) as req:
-                file_dir = gettempdir() + "/" + "subtitle.json"
-                with open(file_dir, "wb") as f:
-                    f.write(await req.content.read())
+            req = await get_session().request("GET", url)
+            file_dir = gettempdir() + "/" + "subtitle.json"
+            with open(file_dir, "wb") as f:
+                f.write(req.content)
             export_ass_from_json(file_dir, out)
             return
     raise ValueError("没有找到指定字幕")
@@ -189,9 +189,8 @@ async def make_ass_file_danmakus_protobuf(
 async def make_ass_file_danmakus_xml(
     obj: Union[Video, Episode, CheeseVideo],
     page: int = None,
-    cid: int = None,
     out=None,
-    credential=None,
+    cid: int = None,
     font_name="Simsun",
     font_size=25.0,
     alpha=1,
@@ -207,7 +206,6 @@ async def make_ass_file_danmakus_xml(
         page(int)                : 分 P 号
         out(str)                 : 输出文件
         cid(int)                 : cid
-        credential(Credential)   : 凭据
         font_name(str)           : 字体
         font_size(float)         : 字体大小
         alpha(float)             : 透明度(0-1)
