@@ -13,11 +13,11 @@ import httpx
 from ..article import Article, ArticleList
 from ..audio import Audio, AudioList
 from ..bangumi import Bangumi, Episode
+from ..black_room import BlackRoom
 from ..cheese import CheeseList, CheeseVideo
 from ..dynamic import Dynamic
 from ..exceptions import *
-from ..favorite_list import (FavoriteList, FavoriteListType,
-                             get_video_favorite_list)
+from ..favorite_list import FavoriteList, FavoriteListType, get_video_favorite_list
 from ..interactive_video import InteractiveVideo
 from ..live import LiveRoom
 from ..user import ChannelSeries, ChannelSeriesType, User, get_self_info
@@ -44,6 +44,7 @@ class ResourceType(Enum):
     + USER: 用户
     + LIVE: 直播间
     + CHANNEL_SERIES: 合集与列表
+    + BLACK_ROOM: 小黑屋
     """
 
     VIDEO = "video"
@@ -60,21 +61,12 @@ class ResourceType(Enum):
     CHANNEL_SERIES = "channel_series"
     ARTICLE_LIST = "article_list"
     DYNAMIC = "dynamic"
+    BLACK_ROOM = "black_room"
 
 
 async def parse_link(url, credential: Credential = Credential()):
     """
     解析 bilibili url 的函数。
-    可以解析：
-    - 视频
-    - 番剧
-    - 番剧剧集
-    - 收藏夹
-    - 课程视频
-    - 音频
-    - 歌单
-    - 专栏
-    - 用户
 
     Args:
         url(str)              : 链接
@@ -91,6 +83,12 @@ async def parse_link(url, credential: Credential = Credential()):
             sobj[0].credential = credential
             return sobj
 
+        
+        black_room = parse_black_room(url)
+        if not black_room == -1:
+            obj = (black_room, ResourceType.BLACK_ROOM)
+            return obj
+
         url = await get_real_url(url)
 
         # 特殊处理，因为后面会过滤参数，这两项需要参数完成
@@ -174,14 +172,12 @@ def check_short_name(name: str, credential: Credential):
       - rlxxxxxxxxxx
     """
     if name[:2].upper() == "AV":
-        v = (Video(aid=int(name[2:])))
+        v = Video(aid=int(name[2:]))
         info = json.loads(
             httpx.get(
-                "https://api.bilibili.com/x/web-interface/view", 
-                params={
-                    "bvid": v.get_bvid()
-                }, 
-                cookies=credential.get_cookies()
+                "https://api.bilibili.com/x/web-interface/view",
+                params={"bvid": v.get_bvid()},
+                cookies=credential.get_cookies(),
             ).text
         )
         is_interactive = info["data"]["rights"]["is_stein_gate"]
@@ -190,14 +186,12 @@ def check_short_name(name: str, credential: Credential):
         else:
             return (v, ResourceType.VIDEO)
     elif name[:2].upper() == "BV":
-        v = (Video(bvid=name))
+        v = Video(bvid=name)
         info = json.loads(
             httpx.get(
-                "https://api.bilibili.com/x/web-interface/view", 
-                params={
-                    "bvid": v.get_bvid()
-                }, 
-                cookies=credential.get_cookies()
+                "https://api.bilibili.com/x/web-interface/view",
+                params={"bvid": v.get_bvid()},
+                cookies=credential.get_cookies(),
             ).text
         )
         is_interactive = info["data"]["rights"]["is_stein_gate"]
@@ -240,11 +234,9 @@ def parse_video(url, credential: Credential):
             return -1
         info = json.loads(
             httpx.get(
-                "https://api.bilibili.com/x/web-interface/view", 
-                params={
-                    "bvid": v.get_bvid()
-                }, 
-                cookies=credential.get_cookies()
+                "https://api.bilibili.com/x/web-interface/view",
+                params={"bvid": v.get_bvid()},
+                cookies=credential.get_cookies(),
             ).text
         )
         is_interactive = info["data"]["rights"]["is_stein_gate"]
@@ -485,6 +477,7 @@ def parse_space_favorite_list(url, credential):
         return -1
     return -1
 
+
 def parse_article_list(url):
     if url[:41] == "https://www.bilibili.com/read/readlist/rl":
         last_part = int(url[41:].replace("/", ""))
@@ -492,6 +485,7 @@ def parse_article_list(url):
     else:
         return -1
 
+
 def parse_dynamic(url):
     if url[:23] == "https://t.bilibili.com/":
         last_part = url[23:].replace("/", "")
@@ -501,3 +495,16 @@ def parse_dynamic(url):
             return Dynamic(int(last_part))
     else:
         return -1
+
+
+def parse_black_room(url: str):
+    if url.lstrip("https:") == url:
+        url = "https:" + url
+    if url[:39] == 'https://www.bilibili.com/blackroom/ban/':
+        last_part = url[39:].replace("/", "")
+        if last_part == "":
+            return -1
+        else:
+            return BlackRoom(int(last_part))
+    else:
+        return -1
